==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kicker/extensions/kasbar/kasprefsdlg.h <==
/* kasprefsdlg.h
**
** Copyright (C) 2001-2003 Richard Moore <rich@kde.org>
** Contributor: Mosfet
**     All rights reserved.
**
** KasBar is dual-licensed: you can choose the GPL or the BSD license.
** Short forms of both licenses are included below.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
** MA 02111-1307, USA.
*/

/*
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions
** are met:
** 1. Redistributions of source code must retain the above copyright
**    notice, this list of conditions and the following disclaimer.
** 2. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
** ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
** FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
** OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
** HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
** LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
** OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
** SUCH DAMAGE.
*/

/*
** Bug reports and questions can be sent to kde-devel@kde.org
*/
// -*- c++ -*-

#ifndef KASPREFSDLG_H
#define KASPREFSDLG_H

#include <kdialogbase.h>

class QComboBox;
class QCheckBox;
class QSlider;
class QSpinBox;
class KColorButton;
class KConfig;
class KIntSpinBox;

class KasTasker;

/**
 * Prefs dialog for KasBar
 */
class KasPrefsDialog : public KDialogBase
{
   Q_OBJECT

public:
   KasPrefsDialog( KasTasker *kas );
   ~KasPrefsDialog();

   void addLookPage();
   void addThumbsPage();
   void addBehavePage();

protected:
   virtual void accept();

   QComboBox *itemSizeCombo;
   QCheckBox *transCheck;
   QCheckBox *tintCheck;
   KColorButton *tintButton;
   QSlider *tintAmount;
   QCheckBox *thumbsCheck;
   QSlider *thumbSizeSlider;
   QSpinBox *thumbUpdateSpin;
   QCheckBox *notifierCheck;
   QCheckBox *modifiedCheck;
   QCheckBox *showAllWindowsCheck;
   KIntSpinBox *maxBoxesSpin;
   QCheckBox *groupWindowsCheck;

   KasTasker *kasbar;
};

#endif // KASPREFSDLG_H

==> kdebase-3.3.2.tar.bz2: kdebase-3.3.2/kicker/extensions/kasbar/kasprefsdlg.h <==
/* kasprefsdlg.h
**
** Copyright (C) 2001-2004 Richard Moore <rich@kde.org>
** Contributor: Mosfet
**     All rights reserved.
**
** KasBar is dual-licensed: you can choose the GPL or the BSD license.
** Short forms of both licenses are included below.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
** MA 02111-1307, USA.
*/

/*
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions
** are met:
** 1. Redistributions of source code must retain the above copyright
**    notice, this list of conditions and the following disclaimer.
** 2. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
** ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
** FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
** OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
** HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
** LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
** OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
** SUCH DAMAGE.
*/

/*
** Bug reports and questions can be sent to kde-devel@kde.org
*/
// -*- c++ -*-

#ifndef KASPREFSDLG_H
#define KASPREFSDLG_H

#include <kdialogbase.h>

class QComboBox;
class QCheckBox;
class QSlider;
class QSpinBox;
class KColorButton;
class KConfig;
class KIntSpinBox;

class KasTasker;

/**
 * Prefs dialog for KasBar
 */
class KasPrefsDialog : public KDialogBase
{
   Q_OBJECT

public:
   KasPrefsDialog( KasTasker *kas );
   ~KasPrefsDialog();

   void addLookPage();
   void addThumbsPage();
   void addBehavePage();
   void addColorsPage();

protected:
   virtual void accept();

   QComboBox *itemSizeCombo;
   QCheckBox *transCheck;
   QCheckBox *tintCheck;
   KColorButton *tintButton;
   QSlider *tintAmount;
   QCheckBox *thumbsCheck;
   QSlider *thumbSizeSlider;
   QSpinBox *thumbUpdateSpin;
   QCheckBox *notifierCheck;
   QCheckBox *modifiedCheck;
   QCheckBox *progressCheck;
   QCheckBox *showAllWindowsCheck;
   KIntSpinBox *maxBoxesSpin;
   QCheckBox *groupWindowsCheck;
   KColorButton *labelPenButton;
   KColorButton *labelBackgroundButton;
   KColorButton *progressButton;

   KasTasker *kasbar;
};

#endif // KASPREFSDLG_H
